==> open-xchange-core_7.10.1.orig.tar.bz2: open-xchange-core-7.10.1/com.openexchange.chronos.provider.internal/src/com/openexchange/chronos/provider/internal/share/CalendarModuleAdjuster.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.chronos.provider.internal.share;

import static com.openexchange.chronos.provider.internal.Constants.QUALIFIED_ACCOUNT_ID;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import com.openexchange.chronos.exception.CalendarExceptionCodes;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.modules.Module;
import com.openexchange.session.Session;
import com.openexchange.share.ShareTarget;
import com.openexchange.share.core.ModuleAdjuster;
import com.openexchange.tools.id.IDMangler;

/**
 * {@link CalendarModuleAdjuster}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.10.0
 */
public class CalendarModuleAdjuster implements ModuleAdjuster {

    /**
     * Initializes a new {@link CalendarModuleAdjuster}.
     */
    public CalendarModuleAdjuster() {
        super();
    }

    @Override
    public Collection<String> getModules() {
        return Collections.singleton(Module.CALENDAR.getName());
    }

    @Override
    public ShareTarget adjustTarget(ShareTarget target, Session session, int targetUserId) throws OXException {
        return adjustTarget(target);
    }

    @Override
    public ShareTarget adjustTarget(ShareTarget target, int contextId, int requestUserId, int targetUserId) throws OXException {
        return adjustTarget(target);
    }

    private ShareTarget adjustTarget(ShareTarget target) {
        if (null == target || false == target.isFolder()) {
            return target;
        }
        String realFolderId = optRelativeFolderId(target.getFolderToLoad());
        if (null == realFolderId) {
            return target;
        }
        String folderId = getUniqueFolderId(realFolderId);
        return new ShareTarget(target.getModule(), folderId, realFolderId, target.getItem());
    }

    private static String optRelativeFolderId(String folderId) {
        try {
            return getRelativeFolderId(folderId);
        } catch (OXException e) {
            return null;
        }
    }

    private static String getUniqueFolderId(String folderId) {
        if (folderId.startsWith(QUALIFIED_ACCOUNT_ID)) {
            return folderId;
        }
        return QUALIFIED_ACCOUNT_ID + '/' + folderId;
    }

    private static String getRelativeFolderId(String folderId) throws OXException {
        if (null == folderId) {
            throw CalendarExceptionCodes.UNSUPPORTED_FOLDER.create(folderId, "");
        }
        try {
            return String.valueOf(Integer.parseInt(folderId));
        } catch (NumberFormatException e) {
            if (false == folderId.startsWith(QUALIFIED_ACCOUNT_ID)) {
                throw CalendarExceptionCodes.UNSUPPORTED_FOLDER.create(e, folderId, "");
            }
            List<String> components = IDMangler.unmangle(folderId);
            if (3 != components.size()) {
                throw CalendarExceptionCodes.UNSUPPORTED_FOLDER.create(folderId, "");
            }
            return getRelativeFolderId(components.get(2));
        }
    }

}

==> open-xchange-core_7.10.5.orig.tar.bz2: open-xchange-core-7.10.5/com.openexchange.chronos.provider.internal/src/com/openexchange/chronos/provider/internal/share/CalendarModuleAdjuster.java <==
/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.chronos.provider.internal.share;

import static com.openexchange.chronos.provider.internal.Constants.QUALIFIED_ACCOUNT_ID;
import java.sql.Connection;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import com.openexchange.chronos.exception.CalendarExceptionCodes;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.modules.Module;
import com.openexchange.session.Session;
import com.openexchange.share.ShareTarget;
import com.openexchange.share.core.ModuleAdjuster;
import com.openexchange.tools.id.IDMangler;

/**
 * {@link CalendarModuleAdjuster}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.10.0
 */
public class CalendarModuleAdjuster implements ModuleAdjuster {

    /**
     * Initializes a new {@link CalendarModuleAdjuster}.
     */
    public CalendarModuleAdjuster() {
        super();
    }

    @Override
    public Collection<String> getModules() {
        return Collections.singleton(Module.CALENDAR.getName());
    }

    @Override
    public ShareTarget adjustTarget(ShareTarget target, Session session, int targetUserId, Connection connection) throws OXException {
        return adjustTarget(target);
    }

    @Override
    public ShareTarget adjustTarget(ShareTarget target, int contextId, int requestUserId, int targetUserId, Connection connection) throws OXException {
        return adjustTarget(target);
    }

    private ShareTarget adjustTarget(ShareTarget target) {
        if (null == target || false == target.isFolder()) {
            return target;
        }
        String realFolderId = optRelativeFolderId(target.getFolderToLoad());
        if (null == realFolderId) {
            return target;
        }
        String folderId = getUniqueFolderId(realFolderId);
        return new ShareTarget(target.getModule(), folderId, realFolderId, target.getItem());
    }

    private static String optRelativeFolderId(String folderId) {
        try {
            return getRelativeFolderId(folderId);
        } catch (OXException e) {
            return null;
        }
    }

    private static String getUniqueFolderId(String folderId) {
        if (folderId.startsWith(QUALIFIED_ACCOUNT_ID)) {
            return folderId;
        }
        return QUALIFIED_ACCOUNT_ID + '/' + folderId;
    }

    private static String getRelativeFolderId(String folderId) throws OXException {
        if (null == folderId) {
            throw CalendarExceptionCodes.UNSUPPORTED_FOLDER.create(folderId, "");
        }
        try {
            return String.valueOf(Integer.parseInt(folderId));
        } catch (NumberFormatException e) {
            if (false == folderId.startsWith(QUALIFIED_ACCOUNT_ID)) {
                throw CalendarExceptionCodes.UNSUPPORTED_FOLDER.create(e, folderId, "");
            }
            List<String> components = IDMangler.unmangle(folderId);
            if (3 != components.size()) {
                throw CalendarExceptionCodes.UNSUPPORTED_FOLDER.create(folderId, "");
            }
            return getRelativeFolderId(components.get(2));
        }
    }

}
